@@ -35,5 +35,5 @@ class Model:
 
 
 class ModelType(Enum):
-    ACOUSTIC: str = 'AM'
-    LINGUISTIC: str = 'LM'
+    ACOUSTIC = 'AM'
+    LINGUISTIC = 'LM'
