@@ -1,7 +1,7 @@
 import dataclasses
 import time
 from enum import Enum
-from typing import Optional
+from typing import Optional, List
 
 
 class Status(Enum):
@@ -40,6 +40,7 @@ class StreamCreatedEvent(StreamEvent):
     ip: str
     hostname: str
     initial_status: Status
+    models: List[str]
 
 
 @dataclasses.dataclass
