@@ -12,8 +12,8 @@ logger = get_logger(__name__)
 
 
 class TranscriptionResponseFormat(Enum):
-    JSON: str = 'JSON'
-    PLAIN: str = 'PLAIN'
+    JSON = 'JSON'
+    PLAIN = 'PLAIN'
 
 
 class TranscriptionRequest:
